@@ -3,7 +3,7 @@
 #################### user-invisible plot functions ####################
 
 # to plot greyscale/ghost graphs of the age-depth model
-.agedepth.ghost <- function(set=get('info'), d.min=set$d.min, d.max=set$d.max, BCAD=set$BCAD, rotate.axes=FALSE, d.res=400, age.res=400, grey.res=100, dark=c(), colours=rgb(0,0,0,seq(0,1, length=100)), age.lim) {
+.agedepth.ghost <- function(set=get('info'), d.min=set$d.min, d.max=set$d.max, BCAD=set$BCAD, rotate.axes=FALSE, rev.d=FALSE, d.res=400, age.res=400, grey.res=100, dark=c(), colours=rgb(0,0,0,seq(0,1, length=100)), age.lim) {
   dseq <- seq(d.min, d.max, length=d.res)
   if(set$isplum) # plum has a strange feature with a grey shape appearing
     dseq <- dseq[-1] # at dmin. Thus removing the first depth
@@ -17,6 +17,10 @@
   dseq <- dseq[-d.inside]
   }
 
+  if(rotate.axes)
+	  dseq <- rev(dseq)
+  if(rev.d)
+	  dseq <- rev(dseq)
   Bacon.hist(dseq, set, BCAD=BCAD, calc.range=FALSE, draw=FALSE)
   hists <- get('hists')
   scales <- array(0, dim=c(length(dseq), age.res))
@@ -29,10 +33,10 @@
   minmax <- hists[[length(hists)]]$min
   maxmax <- hists[[length(hists)]]$max
   scales <- scales/maxmax # normalise to the height of most precise age estimate
-  scales <<- scales; ageseq <<- ageseq; dseq <<- dseq
   if(length(dark) == 0)
     dark <- 10 * minmax/maxmax
   scales[scales > dark] <- dark
+  dseq <- sort(dseq)
   if(rotate.axes)
     image(ageseq, dseq, t(scales), add=TRUE, col=colours, useRaster=TRUE) else
       image(dseq, ageseq, scales, add=TRUE, col=colours, useRaster=TRUE)
